@@ -26,8 +26,8 @@ TYPES = {
            "(?#username[:password])([a-zA-Z0-9+_-]+(:[^@]+)?)?"
            "(?#@host or file)(@?[a-zA-Z0-9/_.-]+)?"
            "(?#/dbname)(/[a-zA-Z0-9_-]+)?"
-           "(?#?variable=value)(\?[a-zA-Z0-9=_-]+)?$",
-    "swiftdevices": "^(r\d+z\d+-[A-Za-z0-9.-_]+:%PORT%/[^,]+,?)+$",
+           "(?#?variable=value)(\\?[a-zA-Z0-9=_-]+)?$",
+    "swiftdevices": "^(r\\d+z\\d+-[A-Za-z0-9.-_]+:%PORT%/[^,]+,?)+$",
     "username": "^[A-Za-z0-9_-]+$",
     "raw": ""
 }
